Module types

Module types 

Structs

Span
A span represents a single unit of work within a trace
SpanMetadata
Type-specific metadata for spans
Trace
A trace represents a single graph execution run
TraceDetail
Trace detail with all spans
TraceSummary
Summary of a trace for the list view (without full input/output)

Enums

SpanStatus
Status of a span
SpanType
Type of span
TraceStatus
Status of a trace (graph run)