start

Function start 

pub async fn start(
    addr: &str,
    store: Arc<dyn TracingStore>,
    event_bus: EventBus,
    static_dir: Option<&str>,
) -> Result<(), Box<dyn Error>>
Start the tracing web server on the given address.

static_dir is the path to the built frontend assets (e.g., “crates/langgraph-tracing/frontend/dist”). If the directory doesn’t exist, only the API and WebSocket endpoints will be available.