Structs
- Span
- A span represents a single unit of work within a trace
- Span
Metadata - Type-specific metadata for spans
- Trace
- A trace represents a single graph execution run
- Trace
Detail - Trace detail with all spans
- Trace
Summary - Summary of a trace for the list view (without full input/output)
Enums
- Span
Status - Status of a span
- Span
Type - Type of span
- Trace
Status - Status of a trace (graph run)